#
# spec file for package python-fasteners
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-fasteners
Version:        0.19
Release:        1.1
Summary:        A python package that provides useful locks
License:        Apache-2.0
URL:            https://github.com/harlowja/fasteners
Source:         https://github.com/harlowja/fasteners/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}-gh.tar.gz
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module diskcache}
BuildRequires:  %{python_module eventlet}
BuildRequires:  %{python_module more-itertools}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module testtools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-more-itertools
Requires:       python-six
BuildArch:      noarch
%python_subpackages

%description
A python package that provides useful locks
It includes the following.
 * Locking decorator
 * Reader-writer locks
 * Inter-process locks
 * Generic helpers

%prep
%setup -q -n fasteners-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc CHANGELOG.md README.md
%{python_sitelib}/*

%changelog
* Wed Sep 27 2023 ecsos <ecsos@opensuse.org>
- Update to 0.19
  - Add .acquire_read_lock, .release_read_lock, .acquire_write_lock,
    and .release_write_lock methods to the inter thread
    ReaderWriterLock as was promised in the README.
  - Remove support for python 3.7 and pypy 3.7. It should still work,
    but is no longer tested.
  - Add support for pypy 3.10 and python 3.11
- Changes from 0.18
  - Reshuffle the process lock code and properly document it.
  - Revamp the docs and switch from sphinx to mkdocs
  - Remove difficult to use tread lock features from docs
  - Bring back support for eventlet spawn_n
  - Remove support for python3.6. It should still work, but is no
    longer tested.
- Add %%{?sle15_python_module_pythons}
* Mon Sep 19 2022 Dirk Müller <dmueller@suse.com>
- update to 0.17.3:
  * Allow writer to become a reader in thread ReaderWriter lock
  * Remove unnecessary setuptools pin
  * Switch to the modern python package build infrastructure
  * Remove support for python 3.5 and earlier, including 2.7
  * Add support for python 3.9 and 3.10
  * Fix a conflict with django lock
  * Add __version__ and __all__ attributes
  * Fix a failure to parse README as utf-8
  * Move from nosetest to pytest and cleanup testing infrastructure
* Sun Aug  1 2021 Dirk Müller <dmueller@suse.com>
- update to 0.16.3:
  * Move from travis and appveyor to github actions
* Sun Jun  6 2021 Dirk Müller <dmueller@suse.com>
- update to 0.16.1:
  * Add interprocess reader writer lock
  * Improve README
  * remove unused eventlet import
  * use stdlib monotonic instead of external for python >= 3.4
  * Add testing for additional python versions
  * Remove python 2.6 support
  * Remove eventlet dependency and use threading.current_thread instead
* Mon Mar 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Fri Dec 20 2019 Dirk Mueller <dmueller@suse.com>
- revert back to 0.14.1 as 0.15 is blacklisted in OpenDev due
  to races with eventlet
* Fri Jun  7 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.15
  * Welcome back alive!
  * Drop Python 2.6
  * TST: check exitcodes of child processes
  * TST: fix multiplatform support for process lock tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed May  3 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Fix source URL.
* Thu Dec 17 2015 tbechtold@suse.com
- update to 0.14.1:
  * Allow providing a custom exception logger
    to 'locked' decorator
  * Allow providing a custom logger to process
    lock class
  * Fix issue #12
* Sun Oct  4 2015 tbechtold@suse.com
- update to 0.13.0:
  * Fix 'ensure_tree' check on freebsd
* Fri Jul  3 2015 dmueller@suse.com
- fix requires
* Wed Jun 24 2015 tbechtold@suse.com
- Initial packaging
